==> languagetool-wikipedia-2.3.1-sources.jar: org/languagetool/dev/index/MatchingSentence.java <==
/* LanguageTool, a natural language style checker
 * Copyright (C) 2012 Daniel Naber (http://www.danielnaber.de)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
 * USA
 */
package org.languagetool.dev.index;

import java.util.List;

import org.languagetool.AnalyzedSentence;
import org.languagetool.rules.RuleMatch;

/**
 * A sentence with rule matches.
 */
public class MatchingSentence {

  private final String sentence;
  private final AnalyzedSentence analyzedSentence;
  private final List<RuleMatch> ruleMatches;

  MatchingSentence(String sentence, AnalyzedSentence analyzedSentence, List<RuleMatch> ruleMatches) {
    this.sentence = sentence;
    this.analyzedSentence = analyzedSentence;
    this.ruleMatches = ruleMatches;
  }

  public String getSentence() {
    return sentence;
  }

  public AnalyzedSentence getAnalyzedSentence() {
    return analyzedSentence;
  }

  public List<RuleMatch> getRuleMatches() {
    return ruleMatches;
  }

  @Override
  public String toString() {
    return sentence;
  }
}

==> languagetool-wikipedia-2.4-sources.jar: org/languagetool/dev/index/MatchingSentence.java <==
/* LanguageTool, a natural language style checker
 * Copyright (C) 2012 Daniel Naber (http://www.danielnaber.de)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
 * USA
 */
package org.languagetool.dev.index;

import java.util.List;

import org.languagetool.AnalyzedSentence;
import org.languagetool.rules.RuleMatch;

/**
 * A sentence with rule matches.
 */
public class MatchingSentence {

  private final String sentence;
  private final String source;
  private final AnalyzedSentence analyzedSentence;
  private final List<RuleMatch> ruleMatches;

  MatchingSentence(String sentence, String source, AnalyzedSentence analyzedSentence, List<RuleMatch> ruleMatches) {
    this.sentence = sentence;
    this.source = source;
    this.analyzedSentence = analyzedSentence;
    this.ruleMatches = ruleMatches;
  }

  public String getSentence() {
    return sentence;
  }

  public String getSource() {
    return source;
  }

  public AnalyzedSentence getAnalyzedSentence() {
    return analyzedSentence;
  }

  public List<RuleMatch> getRuleMatches() {
    return ruleMatches;
  }

  @Override
  public String toString() {
    return sentence;
  }
}
